@@ -914,7 +914,7 @@ sub attributes {
                 test       => sub {
                     my ( $val, $conf ) = @_;
                     my $s = $val;
-                    if ( $s =~ s/^logout(?:_(?:sso|app|app_sso))?\s*// ) {
+                    if ( $s =~ s/^logout(?:_(?:sso|app(?:_sso)?))?\s*// ) {
                         return $s =~ m{^(?:https?://.*)?$}
                           ? (1)
                           : ( 0, '__badUrl__' );
